==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/simplemessagestyle.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>SimpleMessageStyle</name>
    <message>
        <source>hh:mm</source>
        <translation>hh:mm</translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
</context>
<context>
    <name>SimpleMessageStylePlugin</name>
    <message>
        <source>Simple Message Style</source>
        <translation>Einfacher Nachrichten Stil</translation>
    </message>
    <message>
        <source>Allows to use a simplified style in message design</source>
        <translation>Erlaubt das Nutzen eines vereinfachten Stils im Nachrichten Design</translation>
    </message>
    <message>
        <source>Simple Style</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SimpleOptionsWidget</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Select font family and size</source>
        <translation>Schriftart und Größe</translation>
    </message>
    <message>
        <source>Select background image</source>
        <translation>Hintergrundbild</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Bilddateien (*.png *.jpg *.bmp *.gif)</translation>
    </message>
</context>
<context>
    <name>SimpleOptionsWidgetClass</name>
    <message>
        <source>Message Style:</source>
        <translation>Nachrichten Stil:</translation>
    </message>
    <message>
        <source>Variant:</source>
        <translation>Variante:</translation>
    </message>
    <message>
        <source>Text Font:</source>
        <translation>Text Schriftart:</translation>
    </message>
    <message>
        <source>Set Font...</source>
        <translation>Schriftart...</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Set Image...</source>
        <translation>Bild setzen...</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/simplemessagestyle.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>SimpleMessageStyle</name>
    <message>
        <source>hh:mm</source>
        <translation>hh:mm</translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
</context>
<context>
    <name>SimpleMessageStylePlugin</name>
    <message>
        <source>Simple Message Style</source>
        <translation>Einfacher Nachrichten Stil</translation>
    </message>
    <message>
        <source>Allows to use a simplified style in message design</source>
        <translation>Erlaubt das Nutzen eines vereinfachten Stils im Nachrichten Design</translation>
    </message>
    <message>
        <source>Simple Style</source>
        <translation>Einfacher Stil</translation>
    </message>
</context>
<context>
    <name>SimpleOptionsWidget</name>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Select font family and size</source>
        <translation>Schriftart und Größe</translation>
    </message>
    <message>
        <source>Select background image</source>
        <translation>Hintergrundbild</translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp *.gif)</source>
        <translation>Bilddateien (*.png *.jpg *.bmp *.gif)</translation>
    </message>
</context>
<context>
    <name>SimpleOptionsWidgetClass</name>
    <message>
        <source>Message Style:</source>
        <translation>Nachrichten Stil:</translation>
    </message>
    <message>
        <source>Variant:</source>
        <translation>Variante:</translation>
    </message>
    <message>
        <source>Text Font:</source>
        <translation>Text Schriftart:</translation>
    </message>
    <message>
        <source>Set Font...</source>
        <translation>Schriftart...</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Hintergrund:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Farbe:</translation>
    </message>
    <message>
        <source>Set Image...</source>
        <translation>Bild setzen...</translation>
    </message>
    <message>
        <source>Enable animation (may be slow)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
